@@ -19,6 +19,7 @@ Utilities for dealing with paths required during model training and inference.
 from typing import Optional
 
 import pathlib
+import shutil
 
 
 CHECKPOINT_DIR = "checkpoints"
@@ -27,6 +28,14 @@ MODELS_DIR = "models"
 TENSORBOARD_DIR = "tensorboard"
 
 
+def clear_training() -> None:
+    r"""
+    Removes checkpoints and tensorboard logs.
+    """
+    shutil.rmtree(CHECKPOINT_DIR)
+    shutil.rmtree(TENSORBOARD_DIR)
+
+
 def get_board_size_str(h: int, w: int) -> str:
     return f"{h}x{w}"
 
